import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [{
        path: '/login',
        component: () =>
            import ('@/views/login/index'),
        hidden: true
    },

    {
        path: '/404',
        component: () =>
            import ('@/views/404'),
        hidden: true
    },

    {
        path: '/',
        component: Layout,
        redirect: '/dashboard',
        children: [{
            path: 'dashboard',
            name: 'Dashboard',
            component: () =>
                import ('@/views/dashboard/index'),
            meta: { title: '主页', icon: 'dashboard' }
        }]
    },

    {
        path: '/circuitInfo',
        component: Layout,
        children: [{
            path: 'index',
            name: 'Form',
            component: () =>
                import ('@/views/circuitInfo/index'),
            meta: { title: '回路信息', icon: 'form' }
        }]
    },
    {
        path: '/dataQuery',
        component: Layout,
        children: [{
            path: 'index',
            name: 'dataQuery',
            component: () =>
                import ('@/views/dataQuery/index'),
            meta: { title: '数据查询', icon: 'form' }
        }]
    },
    {
        path: '/alarmingManage',
        component: Layout,
        children: [{
            path: 'index',
            name: 'alarmingManage',
            component: () =>
                import ('@/views/alarmingManage/index'),
            meta: { title: '告警管理', icon: 'form' }
        }]
    },


    {
        path: '/electric',
        component: Layout,
        redirect: '/electric/xbAnalysis',
        name: 'electric',
        meta: { title: '电能质量', icon: 'el-icon-s-help' },
        children: [{
                path: 'xbAnalysis',
                name: 'xbAnalysis',
                component: () =>
                    import ('@/views/xbAnalysis/index'),
                meta: { title: '谐波分析', icon: 'table' }
            },
            {
                path: 'unbanlanceAnalysis',
                name: 'unbanlanceAnalysis',
                component: () =>
                    import ('@/views/unbanlanceAnalysis/index'),
                meta: { title: '三相不平衡分析', icon: 'tree' }
            }
        ]
    },

    {
        path: '/electData',
        component: Layout,
        children: [{
            path: 'index',
            name: 'electData',
            component: () =>
                import ('@/views/electData/index'),
            meta: { title: '电子资料', icon: 'form' }
        }]
    },
    {
        path: '/mochaOper',
        component: Layout,
        children: [{
            path: 'index',
            name: 'mochaOper',
            component: () =>
                import ('@/views/mochaOper/index'),
            meta: { title: '运维管理', icon: 'form' }
        }]
    },
    {
        path: '/operReport',
        component: Layout,
        children: [{
            path: 'index',
            name: 'operReport',
            component: () =>
                import ('@/views/operReport/index'),
            meta: { title: '运行报告', icon: 'form' }
        }]
    },


    {
        path: '/form',
        component: Layout,
        hidden: true,
        children: [{
            path: 'index',
            name: 'Form',
            component: () =>
                import ('@/views/form/index'),
            meta: { title: 'Form', icon: 'form' }
        }]
    },
    {
        path: '/systemConfig',
        component: Layout,
        redirect: '/systemConfig/menu1',
        name: 'systemConfig',
        meta: {
            title: '系统配置',
            icon: 'nested'
        },
        children: [{
                path: 'siteEntry',
                component: () =>
                    import ('@/views/systemConfig/siteEntry/index'),
                name: 'siteEntry',
                meta: { title: '站点录入', icon: 'table' }
            },
            {
                path: 'deviceEntry',
                component: () =>
                    import ('@/views/systemConfig/deviceEntry/index'),
                name: 'deviceEntry',
                meta: { title: '设备录入', icon: 'table' }
            }
        ]
    },

    {
        path: '/nested',
        component: Layout,
        redirect: '/nested/menu1',
        name: 'Nested',
        hidden: true,
        meta: {
            title: 'Nested',
            icon: 'nested'
        },
        children: [{
                path: 'menu1',
                component: () =>
                    import ('@/views/nested/menu1/index'), // Parent router-view
                name: 'Menu1',
                meta: { title: 'Menu1' },
                children: [{
                        path: 'menu1-1',
                        component: () =>
                            import ('@/views/nested/menu1/menu1-1'),
                        name: 'Menu1-1',
                        meta: { title: 'Menu1-1' }
                    },
                    {
                        path: 'menu1-2',
                        component: () =>
                            import ('@/views/nested/menu1/menu1-2'),
                        name: 'Menu1-2',
                        meta: { title: 'Menu1-2' },
                        children: [{
                                path: 'menu1-2-1',
                                component: () =>
                                    import ('@/views/nested/menu1/menu1-2/menu1-2-1'),
                                name: 'Menu1-2-1',
                                meta: { title: 'Menu1-2-1' }
                            },
                            {
                                path: 'menu1-2-2',
                                component: () =>
                                    import ('@/views/nested/menu1/menu1-2/menu1-2-2'),
                                name: 'Menu1-2-2',
                                meta: { title: 'Menu1-2-2' }
                            }
                        ]
                    },
                    {
                        path: 'menu1-3',
                        component: () =>
                            import ('@/views/nested/menu1/menu1-3'),
                        name: 'Menu1-3',
                        meta: { title: 'Menu1-3' }
                    }
                ]
            },
            {
                path: 'menu2',
                component: () =>
                    import ('@/views/nested/menu2/index'),
                name: 'Menu2',
                meta: { title: 'menu2' }
            }
        ]
    },
    {
        path: '/form',
        component: Layout,
        hidden: true,
        children: [{
            path: 'index',
            name: 'Form',
            component: () =>
                import ('@/views/form/index'),
            meta: { title: 'Form', icon: 'form' }
        }]
    },

    {
        path: 'external-link',
        component: Layout,
        hidden: true,
        children: [{
            path: 'https://panjiachen.github.io/vue-element-admin-site/#/',
            meta: { title: 'External Link', icon: 'link' }
        }]
    },

    // 404 page must be placed at the end !!!
    { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
    const newRouter = createRouter()
    router.matcher = newRouter.matcher // reset router
}

export default router